from setuptools import setup, find_packages

setup(
    name = "EhanguyKvan",
    version = "0.1.3",
    keywords = ("pip", "codemao"),
    description = "自制的一个杂库，目前推广于codemao平台",
    license = "MIT Licence",
    url = "https://ehanguykvan.github.io/EhanguyKvan/EhanguyKvan.py",
    author = "EhanguyKvan",
    author_email = "1162971013@qq.com",
    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = []
)
